@@ -11,7 +11,7 @@ use Hash::FieldHash ':all';
 
 fieldhash my %graph => 'graph';
 
-our $VERSION = '1.06';
+our $VERSION = '1.08';
 
 # -----------------------------------------------
 
@@ -155,7 +155,7 @@ sub _init
 		 global => {directed => 1},
 		 graph  => {rankdir => 'TB'},
 		 logger => '',
-		 node   => {color => 'darkblue', shape => 'oval'},
+		 node   => {color => 'blue', shape => 'oval'},
 		);
 	$self = from_hash($self, $arg);
 
@@ -219,7 +219,7 @@ L<GraphViz2::Parse::Regexp> - Visualize a Perl regular expression as a graph
 		 global => {directed => 1},
 		 graph  => {rankdir => 'TB'},
 		 logger => $logger,
-		 node   => {color => 'darkblue', shape => 'oval'},
+		 node   => {color => 'blue', shape => 'oval'},
 		);
 	my($g) = GraphViz2::Parse::Regexp -> new(graph => $graph);
 	
