@@ -11,7 +11,7 @@ use XML::Tiny;
 
 fieldhash my %graph => 'graph';
 
-our $VERSION = '1.06';
+our $VERSION = '1.08';
 
 # ------------------------------------------------
 
@@ -59,7 +59,7 @@ sub _init
 		 global => {directed => 1},
 		 graph  => {rankdir => 'TB'},
 		 logger => '',
-		 node   => {color => 'darkblue', shape => 'oval'},
+		 node   => {color => 'blue', shape => 'oval'},
 		);
 	$self = from_hash($self, $arg);
 
@@ -123,7 +123,7 @@ L<GraphViz2::Parse::XML> - Visualize XML as a graph
 		 global => {directed => 1},
 		 graph  => {rankdir => 'TB'},
 		 logger => $logger,
-		 node   => {color => 'darkblue', shape => 'oval'},
+		 node   => {color => 'blue', shape => 'oval'},
 		);
 	my($g) = GraphViz2::Parse::XML -> new(graph => $graph);
 	
